<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_9c050c786fc" . "87170cbb84fc" . "6a8b13cb6" => base64_decode("YXR0YWNo" . "bWVudC0="), "_d706c160e45bf7" . "434fff82a5976f0" . "e19" => base64_decode("YXJyYXlfa" . "2V5cw=="), "_97ea09a7faf27c52c6eff69773df1" . "d8a" => base64_decode("dGltZX" . "N0YW1w"), "_6e1c717cf3cbf1af982ed74d433" . "6b7f1" => base64_decode("Ym9k" . "eS1o" . "dG1s"), "_44e986c04f41a08b56a383c7b3a" . "88ee2" => base64_decode("c2Vu" . "ZGVy"), "_a1e707d02a236dadebd15a45e6" . "5ebdb6" => base64_decode("YXR0YWN" . "obWVudC" . "1jb3Vud" . "A=="), "_f39f5346e313e4dd1ac3a7bd8032be" . "da" => base64_decode("c3Vic3RyX2NvbXBhcm" . "U="), "_618a4aeb9fec" . "c4592a4521f34" . "876fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_956cd32298a229f9768" . "f1096f077ace3" => base64_decode("Ym9keS1wbGFpbg" . "=="), "_1d6c68a0262e8fa0bed1215" . "b7224a98e" => base64_decode("cmVjaXBpZ" . "W50"), "_8c575917cbaedf1e7e" . "fae84939402bff" => base64_decode("U3ViamVjdA" . "=="), "_f589476007fa133f457c" . "3ef29ddfa566" => base64_decode("V" . "G" . "8" . "="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_d706c160e45b" . "f7434fff82a59" . "76f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a1e707d02a2" . "36dadebd15a4" . "5e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_f39f5346e313e4dd1ac3a7bd8032b" . "eda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_9c050c78" . "6fc87170c" . "bb84fc6a8" . "b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_1d6c68a" . "0262e8fa" . "0bed1215" . "b7224a98" . "e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_618a4aeb9fe" . "cc4592a4521f" . "34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_f589476007fa133f457c3" . "ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_8c575917cbaed" . "f1e7efae849394" . "02bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_6e1c717cf3cbf1af982ed74d433" . "6b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_956cd32298a22" . "9f9768f1096f07" . "7ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_97ea09a7faf27c52c6eff6977" . "3df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_44e986c04f41a08b56a" . "383c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}