<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_9b16fa2683095e67d7c8b265a" . "8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZWNl" . "aXZlcg=="), "_03b1f0cee835582d1158dce26" . "78b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCBy" . "ZWNlaXZlZCBzdWJzY3JpYmVy"), "_618a4aeb" . "9fecc4592" . "a4521f348" . "76fa29" => base64_decode("ZnJvbQ=" . "="), "proje" . "ct_id" => base64_decode("cHJvamVjdF9pZA" . "=="), "_5d40a2cf1" . "c525fb252b" . "f5599e339f" . "dd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJva" . "mVjdCB3YXMgaWRlbnRpZmllZC" . "Bmb3IgbWFpbDsgc3ViamVjdCA" . "n"), "_f656816961e8573" . "806141c558b184fe" . "2" => base64_decode("c3ViamVjd" . "A=="), "_a3d82c5df38e194c9c73e3ccb" . "4223bbc" => base64_decode("ZW1haWxfZGF0" . "YQ=="), "_460e1aeb" . "3113a1676" . "ce59a8f40" . "431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHByb2plY3" . "Q="), "_bfda889b74ea561b14325e30" . "e7d75426" => base64_decode("Ym9keV9odG" . "1s"), "_67a0d624aebcceb0abd5ce56a53ff06" . "f" => base64_decode("ZGF0" . "ZQ=="), "_376d30c40857357a4d4cbb1" . "ffaa25817" => base64_decode("dG" . "8="), "_e608e5b5c4c34a67ba97ef84c1e" . "16199" => base64_decode("J" . "w" . "=" . "="), "_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128" => base64_decode("Ym9keV90" . "ZXh0"), "_c35473364fa7a05029905" . "8f332ec29c1" => base64_decode("ZXhjZXB0a" . "W9u"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_9b16fa2683095e67d7c8" . "b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_03b1f0cee835582d" . "1158dce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_5d40a2cf1c525fb" . "252bf5599e339fdd" . "0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_e608e5b5c4c34a67ba97e" . "f84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_618a4aeb9fecc4592a45" . "21f34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_376d30c40857357a4d4cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_f656816" . "961e8573" . "806141c5" . "58b184fe" . "2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_ced92d7b391285c8a26846f1f" . "4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_bfda889b74ea561b14325e30e7" . "d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_67a0d624aebcceb0abd5ce5" . "6a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_460e1aeb3" . "113a1676ce" . "59a8f40431" . "d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["proje" . "ct_id"] => $project->GetId(), $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a3d82c5df38e194c" . "9c73e3ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_c35473364fa7a050299058f332" . "ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}